@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      
+// RCS-ID:      $Id: compat.h,v 1.22 2003/05/05 20:38:41 mbarbon Exp $
 // Copyright:   (c) 2000-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -14,7 +14,7 @@
 #include <patchlevel.h>
 #endif
 
-// < 5.6 does not define PERL_
+// version < 5.6 does not define PERL_
 #ifdef PERL_REVISION
 #define WXPERL_P_VERSION_EQ( V, S, P ) \
  ( ( PERL_REVISION == (V) ) && ( PERL_VERSION == (S) ) && ( PERL_SUBVERSION == (P) ) )
@@ -44,31 +44,6 @@
    ( wxMAJOR_VERSION == (V) && wxMINOR_VERSION < (S) ) || \
    ( wxMAJOR_VERSION == (V) && wxMINOR_VERSION == (S) && wxRELEASE_NUMBER <= (P) ) )
 
-#if WXPERL_P_VERSION_GE( 5, 4, 0 ) && !WXPERL_P_VERSION_GE( 5, 5, 0 )
-
-// some functions have changed from char* to const char*, and I want
-// a stronger type check (under Perl 5.6 CHAR_P is defined to
-// an empty string)
-#define CHAR_P      (char*)
-#define get_sv      perl_get_sv
-#define get_av      perl_get_av
-#define call_sv     perl_call_sv
-#define eval_pv     perl_eval_pv
-#define call_method perl_call_method
-#define require_pv perl_require_pv
-#define call_argv perl_call_argv
-
-#define PL_sv_undef sv_undef
-#define PL_sv_yes   sv_yes
-#define PL_sv_no    sv_no
-
-#define PL_na       na
-
-#define newSVuv( val ) ( newSViv( (IV)(UV)( val ) ) )
-#define SvPV_nolen( s ) SvPV( (s), PL_na )
-
-#endif
-
 #if WXPERL_P_VERSION_GE( 5, 5, 0 ) && !WXPERL_P_VERSION_GE( 5, 6, 0 )
 
 #define CHAR_P (char*)
