@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     30/ 3/2002
-// RCS-ID:      
-// Copyright:   (c) 2002 Mattia Barbon
+// RCS-ID:      $Id: event.h,v 1.5 2003/05/05 20:38:41 mbarbon Exp $
+// Copyright:   (c) 2002-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -20,16 +20,9 @@ class wxPlEvent:public wxEvent
     WXPLI_DECLARE_V_CBACK();
 public:
     wxPlEvent( const char* package, int id, wxEventType eventType )
-#if WXPERL_W_VERSION_GE( 2, 3, 0 )
         : wxEvent( id, eventType ),
-#else
-        : wxEvent( id ),
-#endif
           m_callback( "Wx::PlEvent" )
     {
-#if !WXPERL_W_VERSION_GE( 2, 3, 0 )
-        m_eventType = eventType;
-#endif
         m_callback.SetSelf( wxPli_make_object( this, package ), true );
     }
 
@@ -100,17 +93,10 @@ public:
     wxPlThreadEvent() : m_data( 0 ) {}
     wxPlThreadEvent( const char* package, int id, wxEventType eventType,
                      SV* data )
-#if WXPERL_W_VERSION_GE( 2, 3, 0 )
         : wxEvent( id, eventType ),
-#else
-        : wxEvent( id ),
-#endif
           m_data( data )
     {
         dTHX;
-#if !WXPERL_W_VERSION_GE( 2, 3, 0 )
-        m_eventType = eventType;
-#endif
         SvREFCNT_inc( m_data );
     }
 
