@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        ext/socket/lib/Wx/Socket.pm
+## Name:        Socket.pm
 ## Purpose:     Wx::Socket
 ## Author:      Graciliano M. P.
 ## Modified by:
 ## Created:     27/02/2003
-## RCS-ID:      $Id: Socket.pm,v 1.10.2.1 2005/08/15 16:17:15 mbarbon Exp $
-## Copyright:   (c) 2003-2004 Graciliano M. P.
+## RCS-ID:      
+## Copyright:   (c) 2003 Graciliano M. P.
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -22,14 +22,10 @@ $VERSION = '0.01';
 Wx::wx_boot( 'Wx::Socket', $VERSION );
 
 no strict ;
-package Wx::DatagramSocket ; @ISA = qw(Wx::SocketBase) ;
 package Wx::SocketClient ; @ISA = qw(Wx::SocketBase) ;
 package Wx::SocketServer ; @ISA = qw(Wx::SocketBase) ;
+package Wx::SocketBase ; @ISA = qw(Wx::Socket Wx::Object) ;
 package Wx::SocketEvent ; @ISA = qw(Wx::Event) ;
-package Wx::IPaddress ; @ISA = qw(Wx::SockAddress);
-package Wx::IPV4address ; @ISA = qw(Wx::IPaddress);
-package Wx::IPV6address ; @ISA = qw(Wx::IPaddress);
-package Wx::UNIXaddress ; @ISA = qw(Wx::SockAddress);
 use strict ;
 
 #####################
@@ -56,7 +52,7 @@ sub MAKE_EVT {
   &ENABLE_SKEVT($sock , $handler , $callback) ;
   $sock->{_WXEVT}{SUB}{$type} = $callback ;
   if (!$sock->{_WXEVT}{CONNECT}) {
-    $handler->Connect( $sock->{_WXEVT}{ID} , -1 , &Wx::wxEVT_SOCKET ,
+    $handler->Connect( $handler , $sock->{_WXEVT}{ID} , &Wx::wxEVT_SOCKET ,
                        sub{ &CHECK_EVT_TYPE($sock,@_) } );
     $sock->{_WXEVT}{CONNECT} = 1 ;
   }
@@ -148,7 +144,7 @@ Wx::Socket - wxSocket* classes
 
 =head1 METHODS
 
-All the methods work as in wxWidgets (see the documentation).
+All the methods work as in wxWindows (see the documentation).
 
 The functions for reading data (Read, ReadMsg, Peek) take 3 arguments,
 like the Perl read() function:
@@ -179,7 +175,7 @@ The events are:
     EVT_SOCKET_CONNECTION
     EVT_SOCKET_LOST
 
-The EVT_SOCKET works as in wxWidgets, the others are wxPerl extensions.
+The EVT_SOCKET works as in wxWindows, the others are wxPerl extensions.
 
 Note that EVT_SOCKET events of wxSocketClient and wxSocketServer
 work differently than other event types.
