@@ -4,16 +4,14 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:      4/ 4/2002
-// RCS-ID:      
-// Copyright:   (c) 2002 Mattia Barbon
+// RCS-ID:      $Id: xr_constants.cpp,v 1.4 2003/05/05 20:38:42 mbarbon Exp $
+// Copyright:   (c) 2002-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
 
 #include "cpp/constants.h"
 
-#if WXPERL_W_VERSION_GE( 2, 3, 3 )
-
 #include "wx/xrc/xmlres.h"
 
 double xrc_constant( const char* name, int arg )
@@ -41,4 +39,3 @@ double xrc_constant( const char* name, int arg )
 
 wxPlConstants xrc_module( &xrc_constant );
 
-#endif
