@@ -5,8 +5,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/03/2003
-## RCS-ID:      $Id: xsubppp.pl,v 1.8 2004/12/21 20:57:45 mbarbon Exp $
-## Copyright:   (c) 2003-2004 Mattia Barbon
+## RCS-ID:      $Id: xsubppp.pl,v 1.5 2003/04/25 20:13:16 mbarbon Exp $
+## Copyright:   (c) 2003 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -203,10 +203,6 @@ sub print {
   my $state = shift;
   my $out = '';
   my $pcname = $this->perl_name;
-
-  if( !defined $state->{current_module} ) {
-    die "No current module: remember to add a %module{} directive";
-  }
   my $cur_module = $state->{current_module}->to_string;
 
   $out .= <<EOT;
@@ -347,7 +343,6 @@ sub print {
 
   if( $this->code ) {
     $code = "  CODE:\n    " . join( "\n", @{$this->code} ) . "\n";
-    $output = "  OUTPUT: RETVAL\n" if $code =~ m/RETVAL/;
   }
 
   $out .= "$retstr\n";
@@ -360,9 +355,7 @@ sub print {
 
 sub perl_function_name { $_[0]->perl_name }
 
-=begin documentation
-
-XSP::Parser::_call_code( argument_string )
+=begin documentation XSP::Parser::_call_code( argument_string )
 
 Return something like "foo( $argument_string )".
 
